@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use DateTime::Format::RFC3339;
 use URI;
@@ -53,3 +53,43 @@ sub _refresh_raw_content {
 ## use critic
 
 1;
+
+# ABSTRACT: A shared role for all PT resources
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+WebService::PivotalTracker::Entity - A shared role for all PT resources
+
+=head1 VERSION
+
+version 0.08
+
+=head1 DESCRIPTION
+
+This role has no user-facing parts.
+
+=for Pod::Coverage .*
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/WebService-PivotalTracker/issues>.
+
+=head1 AUTHOR
+
+Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by MaxMind, Inc.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
+=cut
