@@ -4,15 +4,16 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Params::ValidationCompiler qw( validation_for );
 use WebService::PivotalTracker::Comment;
 use WebService::PivotalTracker::Label;
+use WebService::PivotalTracker::Person;
 use WebService::PivotalTracker::PropertyAttributes;
 use WebService::PivotalTracker::Types qw(
     ArrayRef CommentObject DateTimeObject LabelObject Maybe
-    NonEmptyStr Num PositiveInt Str StoryState StoryType Uri
+    NonEmptyStr Num PersonObject PositiveInt Str StoryState StoryType Uri
 );
 
 use Moo;
@@ -78,6 +79,19 @@ has labels => (
     clearer  => '_clear_labels',
 );
 
+has requested_by => (
+    is      => 'ro',
+    isa     => PersonObject,
+    lazy    => 1,
+    default => sub {
+        my $self = shift;
+        WebService::PivotalTracker::Person->new(
+            raw_content => $self->raw_content->{requested_by},
+            pt_api      => $self->_pt_api,
+        );
+    },
+);
+
 with 'WebService::PivotalTracker::Entity';
 
 ## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
@@ -242,3 +256,156 @@ sub _self_uri {
 }
 
 1;
+
+# ABSTRACT: A single story
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+WebService::PivotalTracker::Story - A single story
+
+=head1 VERSION
+
+version 0.08
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+This class represents a single story.
+
+=for Test::Synopsis my $project;
+
+  my $iterations = $project->stories( ... );
+
+=head1 ATTRIBUTES
+
+This class provides the following attribute accessor methods. Each one
+corresponds to a property defined by the L<PT REST API V5 story resource
+docs|https://www.pivotaltracker.com/help/api/rest/v5#story_resource>.
+
+=head2 id
+
+=head2 project_id
+
+=head2 name
+
+=head2 description
+
+The description in Markdown.
+
+=head2 story_type
+
+=head2 current_state
+
+=head2 estimate
+
+=head2 accepted_at
+
+This will be returned as a L<DateTime> object.
+
+=head2 deadline
+
+This will be returned as a L<DateTime> object.
+
+=head2 requested_by_id
+
+=head2 owner_ids
+
+An array reference.
+
+=head2 task_ids
+
+An array reference.
+
+=head2 follower_ids
+
+An array reference.
+
+=head2 created_at
+
+This will be returned as a L<DateTime> object.
+
+=head2 updated_at
+
+This will be returned as a L<DateTime> object.
+
+=head2 url
+
+This will be returned as a L<URI> object.
+
+=head2 kind
+
+=head2 raw_content
+
+The raw JSON used to create this object.
+
+=head1 METHODS
+
+This class provides the following methods:
+
+=head2 $story->comments
+
+This method returns an array reference of
+L<WebService::PivotalTracker::Comment> objects.
+
+=head2 $story->labels
+
+This method returns an array reference of L<WebService::PivotalTracker::Label>
+objects.
+
+=head2 $story->requested_by
+
+This method returns a L<WebService::PivotalTracker::Person> representing the
+person who is the requester for the story.
+
+=head2 $story->update( ... )
+
+This method will update the story's properties as specified.
+
+=head2 $story->add_comment( ... )
+
+This method adds a comment to a story. It accepts two arguments:
+
+=over 4
+
+=item * text
+
+The text of the comment in Markdown.
+
+This is required.
+
+=item * person_id
+
+By default, the comment will be attributed to whoever owns the token, but you
+can use this to override that.
+
+=back
+
+=head2 $story->add_label( ... )
+
+This method accepts a single argument, C<name>, which is the name of the label
+to add.
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/WebService-PivotalTracker/issues>.
+
+=head1 AUTHOR
+
+Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by MaxMind, Inc.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
+=cut
